//
// Test application
//
// AvkonVideoOverlay
// avkonvideooverlayappui.cpp
//

#include "avkonvideooverlaydefs.h"
#include "avkonvideooverlayappui.h"
#include "avkonvideooverlayview.h"
#include "overlaycontrol.h"
#include "solidcontrol.h"
#include "videocontrol.h"

#include <eikbtgpc.h>
#include <eikmenup.h>

const TInt KLskPosition = 0;

#define ADD_SOLID_CONTROL
#define SOLID_CONTROL_GRAPHICS_SURFACE
#define ADD_VIDEO_CONTROL
#define ADD_OVERLAY_CONTROL
//#define OVERLAY_TOP_LEVEL

void CAvkonVideoOverlayAppUi::ConstructL()
	{
	BaseConstructL();
	
	iAppView = CAvkonVideoOverlayAppView::NewL();
	AddToStackL(iAppView);
	CCoeControl *control = iAppView;
	CCoeControlArray *array = &iAppView->Components();

#ifdef ADD_SOLID_CONTROL
    CSolidControl* solidControl = new (ELeave) CSolidControl;
    array->AppendLC(solidControl);
#   ifdef SOLID_CONTROL_GRAPHICS_SURFACE
    solidControl->ConstructL(ETrue, control);
#   else
    solidControl->ConstructL(EFalse, control);
#   endif
    CleanupStack::Pop(solidControl);
    control = solidControl;
    array = &solidControl->Components();
#endif

#ifdef ADD_VIDEO_CONTROL
	CVideoControl* videoControl = new (ELeave) CVideoControl;
    array->AppendLC(videoControl);
    videoControl->ConstructL(control);
    CleanupStack::Pop(videoControl);
    control = videoControl;
    array = &videoControl->Components();
#endif

#ifdef ADD_OVERLAY_CONTROL
    COverlayControl *overlayControl = new (ELeave) COverlayControl;
    array->AppendLC(overlayControl);
#   ifdef OVERLAY_TOP_LEVEL
    overlayControl->ConstructL();
#   else
    overlayControl->ConstructL(control);
#   endif
    CleanupStack::Pop(overlayControl);
    control = overlayControl;
    array = &overlayControl->Components();
#endif

	iIdleTimer = CPeriodic::NewL(CActive::EPriorityStandard);	
    iAppView->SetRect(ClientRect());
	iAppView->ActivateL();
	iAppView->DrawNow();
	Cba()->SetCommandL(KLskPosition, EAknSoftkeyOptions, _L("Options"));
	}


//-----------------------------------------------------------------------------
// CEikAppUi
//-----------------------------------------------------------------------------

CAvkonVideoOverlayAppUi::~CAvkonVideoOverlayAppUi()
	{
	if(iAppView)
		{
		RemoveFromStack(iAppView);
		delete iAppView;
		}
	delete iIdleTimer;
	}

void CAvkonVideoOverlayAppUi::HandleForegroundEventL(TBool aForeground)
	{
	if(!aForeground && iIdleTimer)
		{
		if(!iIdleTimer->IsActive())
			{
			iIdleTimer->Start(KIdleTimeOut, 0, TCallBack(BackgroundCallBack, this) );
			}
		}
	}

TInt CAvkonVideoOverlayAppUi::BackgroundCallBack(TAny* aSelf)
	{
	CAvkonVideoOverlayAppUi* self = static_cast<CAvkonVideoOverlayAppUi*>(aSelf);
	self->BringToForeground();
	return KErrNone;
	}

void CAvkonVideoOverlayAppUi::BringToForeground()
	{
	iIdleTimer->Cancel();
	const TInt err = iCoeEnv->WsSession().SetWindowGroupOrdinalPosition(iCoeEnv->RootWin().Identifier(), 0);
	}

void CAvkonVideoOverlayAppUi::DynInitMenuPaneL(
    TInt /*aResourceId*/, CEikMenuPane* aMenuPane)
    {
    TInt position;

    if(!aMenuPane->MenuItemExists(EAvkonVideoOverlayCmdA, position))
        {
        CEikMenuPaneItem::SData item;
        item.iText.Copy(_L("Option A"));
        item.iCommandId = EAvkonVideoOverlayCmdA;
        item.iFlags = 0;
        item.iCascadeId = 0;
        item.iExtraText = KNullDesC;
        aMenuPane->AddMenuItemL(item);
        }

	if(!aMenuPane->MenuItemExists(EAvkonVideoOverlayCmdB, position))
        {
        CEikMenuPaneItem::SData item;
        item.iText.Copy(_L("Option B"));
        item.iCommandId = EAvkonVideoOverlayCmdB;
        item.iFlags = 0;
        item.iCascadeId = 0;
        item.iExtraText = KNullDesC;
        aMenuPane->AddMenuItemL(item);
        }

    if(!aMenuPane->MenuItemExists(EAknCmdExit, position))
        {
        CEikMenuPaneItem::SData item;
        item.iText.Copy(_L("Exit"));
        item.iCommandId = EAknCmdExit;
        item.iFlags = 0;
        item.iCascadeId = 0;
        item.iExtraText=KNullDesC;
        aMenuPane->AddMenuItemL(item);
        }
    }

void CAvkonVideoOverlayAppUi::HandleCommandL(TInt aCommand)
	{
	switch (aCommand)
		{
		case EAvkonVideoOverlayCmdA:
			{
			User::InfoPrint(_L("Option A"));
			break;
			}

		case EAvkonVideoOverlayCmdB:
			{
			User::InfoPrint(_L("Option B"));
			break;
			}

		case EAknSoftkeyBack:
		case EEikCmdExit:
			{
			Exit();
			break;
			}
		}
	}

